@@ -28,12 +28,14 @@ def get_db_info():
             "Obtaining 2D dataset 1.1k ...",
             "https://www.nature.com/articles/s41524-020-00440-1",
         ],
+        # https://doi.org/10.6084/m9.figshare.6815705
         "dft_3d": [
-            "https://ndownloader.figshare.com/files/26808914",
-            "d3-3-12-2021.json",
-            "Obtaining 3D dataset 43k ...",
+            "https://ndownloader.figshare.com/files/28034994",
+            "d3-5-16-2021.json",
+            "Obtaining 3D dataset 48k ...",
             "https://www.nature.com/articles/s41524-020-00440-1",
         ],
+        # https://doi.org/10.6084/m9.figshare.6815699
         "cfid_3d": [
             "https://ndownloader.figshare.com/files/26808914",
             "d3-3-12-2021.json",
@@ -89,9 +91,9 @@ def get_db_info():
             "https://www.nature.com/articles/sdata201612",
         ],
         "qm9": [
-            "https://ndownloader.figshare.com/files/25159592",
+            "https://ndownloader.figshare.com/files/27627596",
             "qm9_data_cfid.json",
-            "Obtaining 2DMatPedia dataset 6k...",
+            "Obtaining QM9 dataset 134k...",
             "https://www.nature.com/articles/sdata201422",
         ],
         "aflow1": [
@@ -336,6 +338,18 @@ def get_hk_tb(k=np.array([0, 0, 0]), w=[]):
     return hk
 
 
+"""
+QM9 xyz file
+>>> def get_val(filename=''):
+        f=open(filename,'r')
+        lines=f.read().splitlines()
+        f.close()
+        info={}
+        for i in range(len(attr_index)):
+           info[attr_index[i]]=float(lines[1].split()[i+2])
+        return info
+"""
+
 """
 if __name__ == "__main__":
 
